Reahl
=====

Reahl comprises a number of projects that help with the development 
of interactive web applications. 

Reahl-web is a web application framework that allows a programmer to work
in terms of useful abstractions—using a single programming language.

The details of how those abstractions are implemented using several
different web technologies are hidden and dealt with for the
programmer.

Reahl-component provides infrastructure for components in any 
application that can also have their own database schemas, configuration, 
internationalisation and more.

The other projects support development of (mostly web) applications, 
regardless of which web framework is used.

The Reahl components reside in one source code tree, each with its own 
LGPL license (see the relevant licenses in each subdirectory).

More details at our website: [Reahl - the Python-only web framework](http://www.reahl.org)

Licensing
=========

This project contains several independently licensed projects in its
source tree.

Please see the LICENSE file in each sub directory for the license that
applies to that sub directory.

The LICENSE.<package-name> file in the top level is the license file
for the package it is named for.

Some sub projects include other code. The accompanying licenses of
such code is listed in the COPYING file of such sub directory.
